# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SourceRedshift(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'database': 'str',
        'schema': 'str',
        'table_name': 'str',
        'incremental_field': 'str'
    }

    attribute_map = {
        'database': 'database',
        'schema': 'schema',
        'table_name': 'table_name',
        'incremental_field': 'incremental_field'
    }

    def __init__(self, database, schema, table_name, **kwargs):  # noqa: E501
        """SourceRedshift - a model defined in Swagger"""  # noqa: E501

        self._database = None
        self._schema = None
        self._table_name = None
        self._incremental_field = None
        self.discriminator = None

        self.database = database
        self.schema = schema
        self.table_name = table_name
        self.incremental_field = kwargs.pop('incremental_field', None)

    @property
    def database(self):
        """Gets the database of this SourceRedshift.  # noqa: E501

        name of the database in Redshift Cluster  # noqa: E501

        :return: The database of this SourceRedshift.  # noqa: E501
        :rtype: str
        """
        return self._database

    @database.setter
    def database(self, database):
        """Sets the database of this SourceRedshift.

        name of the database in Redshift Cluster  # noqa: E501

        :param database: The database of this SourceRedshift.  # noqa: E501
        :type: str
        """

        self._database = database

    @property
    def schema(self):
        """Gets the schema of this SourceRedshift.  # noqa: E501

        schema which contains the Redshift table  # noqa: E501

        :return: The schema of this SourceRedshift.  # noqa: E501
        :rtype: str
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this SourceRedshift.

        schema which contains the Redshift table  # noqa: E501

        :param schema: The schema of this SourceRedshift.  # noqa: E501
        :type: str
        """

        self._schema = schema

    @property
    def table_name(self):
        """Gets the table_name of this SourceRedshift.  # noqa: E501

        name of Redshift table containing data  # noqa: E501

        :return: The table_name of this SourceRedshift.  # noqa: E501
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this SourceRedshift.

        name of Redshift table containing data  # noqa: E501

        :param table_name: The table_name of this SourceRedshift.  # noqa: E501
        :type: str
        """

        self._table_name = table_name

    @property
    def incremental_field(self):
        """Gets the incremental_field of this SourceRedshift.  # noqa: E501

        field in Redshift source table to monitor for updates  # noqa: E501

        :return: The incremental_field of this SourceRedshift.  # noqa: E501
        :rtype: str
        """
        return self._incremental_field

    @incremental_field.setter
    def incremental_field(self, incremental_field):
        """Sets the incremental_field of this SourceRedshift.

        field in Redshift source table to monitor for updates  # noqa: E501

        :param incremental_field: The incremental_field of this SourceRedshift.  # noqa: E501
        :type: str
        """

        self._incremental_field = incremental_field

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SourceRedshift, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceRedshift):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class InvertedIndexGroupEncodingOptions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'format_version': 'int',
        'group_size': 'int',
        'restart_length': 'int',
        'event_time_codec': 'str',
        'doc_id_codec': 'str'
    }

    attribute_map = {
        'format_version': 'format_version',
        'group_size': 'group_size',
        'restart_length': 'restart_length',
        'event_time_codec': 'event_time_codec',
        'doc_id_codec': 'doc_id_codec'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """InvertedIndexGroupEncodingOptions - a model defined in Swagger"""  # noqa: E501

        self._format_version = None
        self._group_size = None
        self._restart_length = None
        self._event_time_codec = None
        self._doc_id_codec = None
        self.discriminator = None

        self.format_version = kwargs.pop('format_version', None)
        self.group_size = kwargs.pop('group_size', None)
        self.restart_length = kwargs.pop('restart_length', None)
        self.event_time_codec = kwargs.pop('event_time_codec', None)
        self.doc_id_codec = kwargs.pop('doc_id_codec', None)

    @property
    def format_version(self):
        """Gets the format_version of this InvertedIndexGroupEncodingOptions.  # noqa: E501


        :return: The format_version of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :rtype: int
        """
        return self._format_version

    @format_version.setter
    def format_version(self, format_version):
        """Sets the format_version of this InvertedIndexGroupEncodingOptions.


        :param format_version: The format_version of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :type: int
        """

        self._format_version = format_version

    @property
    def group_size(self):
        """Gets the group_size of this InvertedIndexGroupEncodingOptions.  # noqa: E501


        :return: The group_size of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :rtype: int
        """
        return self._group_size

    @group_size.setter
    def group_size(self, group_size):
        """Sets the group_size of this InvertedIndexGroupEncodingOptions.


        :param group_size: The group_size of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :type: int
        """

        self._group_size = group_size

    @property
    def restart_length(self):
        """Gets the restart_length of this InvertedIndexGroupEncodingOptions.  # noqa: E501


        :return: The restart_length of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :rtype: int
        """
        return self._restart_length

    @restart_length.setter
    def restart_length(self, restart_length):
        """Sets the restart_length of this InvertedIndexGroupEncodingOptions.


        :param restart_length: The restart_length of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :type: int
        """

        self._restart_length = restart_length

    @property
    def event_time_codec(self):
        """Gets the event_time_codec of this InvertedIndexGroupEncodingOptions.  # noqa: E501


        :return: The event_time_codec of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :rtype: str
        """
        return self._event_time_codec

    @event_time_codec.setter
    def event_time_codec(self, event_time_codec):
        """Sets the event_time_codec of this InvertedIndexGroupEncodingOptions.


        :param event_time_codec: The event_time_codec of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :type: str
        """

        self._event_time_codec = event_time_codec

    @property
    def doc_id_codec(self):
        """Gets the doc_id_codec of this InvertedIndexGroupEncodingOptions.  # noqa: E501


        :return: The doc_id_codec of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :rtype: str
        """
        return self._doc_id_codec

    @doc_id_codec.setter
    def doc_id_codec(self, doc_id_codec):
        """Sets the doc_id_codec of this InvertedIndexGroupEncodingOptions.


        :param doc_id_codec: The doc_id_codec of this InvertedIndexGroupEncodingOptions.  # noqa: E501
        :type: str
        """

        self._doc_id_codec = doc_id_codec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvertedIndexGroupEncodingOptions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvertedIndexGroupEncodingOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StatusDynamoDbV2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'initial_dump_completion_percentage': 'float',
        'state': 'str',
        'stream_last_processed_at': 'str'
    }

    attribute_map = {
        'initial_dump_completion_percentage': 'initial_dump_completion_percentage',
        'state': 'state',
        'stream_last_processed_at': 'stream_last_processed_at'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """StatusDynamoDbV2 - a model defined in Swagger"""  # noqa: E501

        self._initial_dump_completion_percentage = None
        self._state = None
        self._stream_last_processed_at = None
        self.discriminator = None

        self.initial_dump_completion_percentage = kwargs.pop('initial_dump_completion_percentage', None)
        self.state = kwargs.pop('state', None)
        self.stream_last_processed_at = kwargs.pop('stream_last_processed_at', None)

    @property
    def initial_dump_completion_percentage(self):
        """Gets the initial_dump_completion_percentage of this StatusDynamoDbV2.  # noqa: E501


        :return: The initial_dump_completion_percentage of this StatusDynamoDbV2.  # noqa: E501
        :rtype: float
        """
        return self._initial_dump_completion_percentage

    @initial_dump_completion_percentage.setter
    def initial_dump_completion_percentage(self, initial_dump_completion_percentage):
        """Sets the initial_dump_completion_percentage of this StatusDynamoDbV2.


        :param initial_dump_completion_percentage: The initial_dump_completion_percentage of this StatusDynamoDbV2.  # noqa: E501
        :type: float
        """

        self._initial_dump_completion_percentage = initial_dump_completion_percentage

    @property
    def state(self):
        """Gets the state of this StatusDynamoDbV2.  # noqa: E501

        state of current ingest for this table  # noqa: E501

        :return: The state of this StatusDynamoDbV2.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this StatusDynamoDbV2.

        state of current ingest for this table  # noqa: E501

        :param state: The state of this StatusDynamoDbV2.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def stream_last_processed_at(self):
        """Gets the stream_last_processed_at of this StatusDynamoDbV2.  # noqa: E501

        ISO-8601 date when source was last processed  # noqa: E501

        :return: The stream_last_processed_at of this StatusDynamoDbV2.  # noqa: E501
        :rtype: str
        """
        return self._stream_last_processed_at

    @stream_last_processed_at.setter
    def stream_last_processed_at(self, stream_last_processed_at):
        """Sets the stream_last_processed_at of this StatusDynamoDbV2.

        ISO-8601 date when source was last processed  # noqa: E501

        :param stream_last_processed_at: The stream_last_processed_at of this StatusDynamoDbV2.  # noqa: E501
        :type: str
        """

        self._stream_last_processed_at = stream_last_processed_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatusDynamoDbV2, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatusDynamoDbV2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.status_dynamo_db import StatusDynamoDb  # noqa: F401,E501
from rockset.swagger_client.models.status_dynamo_db_v2 import StatusDynamoDbV2  # noqa: F401,E501


class SourceDynamoDb(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aws_region': 'str',
        'table_name': 'str',
        'current_status': 'StatusDynamoDbV2',
        'rcu': 'int',
        'status': 'StatusDynamoDb'
    }

    attribute_map = {
        'aws_region': 'aws_region',
        'table_name': 'table_name',
        'current_status': 'current_status',
        'rcu': 'rcu',
        'status': 'status'
    }

    def __init__(self, table_name, **kwargs):  # noqa: E501
        """SourceDynamoDb - a model defined in Swagger"""  # noqa: E501

        self._aws_region = None
        self._table_name = None
        self._current_status = None
        self._rcu = None
        self._status = None
        self.discriminator = None

        self.aws_region = kwargs.pop('aws_region', None)
        self.table_name = table_name
        self.current_status = kwargs.pop('current_status', None)
        self.rcu = kwargs.pop('rcu', None)
        self.status = kwargs.pop('status', None)

    @property
    def aws_region(self):
        """Gets the aws_region of this SourceDynamoDb.  # noqa: E501

        AWS region name of DynamoDB table, by default us-west-2 is used  # noqa: E501

        :return: The aws_region of this SourceDynamoDb.  # noqa: E501
        :rtype: str
        """
        return self._aws_region

    @aws_region.setter
    def aws_region(self, aws_region):
        """Sets the aws_region of this SourceDynamoDb.

        AWS region name of DynamoDB table, by default us-west-2 is used  # noqa: E501

        :param aws_region: The aws_region of this SourceDynamoDb.  # noqa: E501
        :type: str
        """

        self._aws_region = aws_region

    @property
    def table_name(self):
        """Gets the table_name of this SourceDynamoDb.  # noqa: E501

        name of DynamoDB table containing data  # noqa: E501

        :return: The table_name of this SourceDynamoDb.  # noqa: E501
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this SourceDynamoDb.

        name of DynamoDB table containing data  # noqa: E501

        :param table_name: The table_name of this SourceDynamoDb.  # noqa: E501
        :type: str
        """

        self._table_name = table_name

    @property
    def current_status(self):
        """Gets the current_status of this SourceDynamoDb.  # noqa: E501

        DynamoDB source status v2  # noqa: E501

        :return: The current_status of this SourceDynamoDb.  # noqa: E501
        :rtype: StatusDynamoDbV2
        """
        return self._current_status

    @current_status.setter
    def current_status(self, current_status):
        """Sets the current_status of this SourceDynamoDb.

        DynamoDB source status v2  # noqa: E501

        :param current_status: The current_status of this SourceDynamoDb.  # noqa: E501
        :type: StatusDynamoDbV2
        """

        self._current_status = current_status

    @property
    def rcu(self):
        """Gets the rcu of this SourceDynamoDb.  # noqa: E501

        Max RCU usage for scan  # noqa: E501

        :return: The rcu of this SourceDynamoDb.  # noqa: E501
        :rtype: int
        """
        return self._rcu

    @rcu.setter
    def rcu(self, rcu):
        """Sets the rcu of this SourceDynamoDb.

        Max RCU usage for scan  # noqa: E501

        :param rcu: The rcu of this SourceDynamoDb.  # noqa: E501
        :type: int
        """

        self._rcu = rcu

    @property
    def status(self):
        """Gets the status of this SourceDynamoDb.  # noqa: E501

        DynamoDB source status  # noqa: E501

        :return: The status of this SourceDynamoDb.  # noqa: E501
        :rtype: StatusDynamoDb
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SourceDynamoDb.

        DynamoDB source status  # noqa: E501

        :param status: The status of this SourceDynamoDb.  # noqa: E501
        :type: StatusDynamoDb
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SourceDynamoDb, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceDynamoDb):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.privilege import Privilege  # noqa: F401,E501


class Role(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'role_name': 'str',
        'description': 'str',
        'owner_email': 'str',
        'created_by': 'str',
        'privileges': 'list[Privilege]',
        'created_at': 'str'
    }

    attribute_map = {
        'role_name': 'role_name',
        'description': 'description',
        'owner_email': 'owner_email',
        'created_by': 'created_by',
        'privileges': 'privileges',
        'created_at': 'created_at'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """Role - a model defined in Swagger"""  # noqa: E501

        self._role_name = None
        self._description = None
        self._owner_email = None
        self._created_by = None
        self._privileges = None
        self._created_at = None
        self.discriminator = None

        self.role_name = kwargs.pop('role_name', None)
        self.description = kwargs.pop('description', None)
        self.owner_email = kwargs.pop('owner_email', None)
        self.created_by = kwargs.pop('created_by', None)
        self.privileges = kwargs.pop('privileges', None)
        self.created_at = kwargs.pop('created_at', None)

    @property
    def role_name(self):
        """Gets the role_name of this Role.  # noqa: E501

        Unique identifier for the role.  # noqa: E501

        :return: The role_name of this Role.  # noqa: E501
        :rtype: str
        """
        return self._role_name

    @role_name.setter
    def role_name(self, role_name):
        """Sets the role_name of this Role.

        Unique identifier for the role.  # noqa: E501

        :param role_name: The role_name of this Role.  # noqa: E501
        :type: str
        """

        self._role_name = role_name

    @property
    def description(self):
        """Gets the description of this Role.  # noqa: E501

        Description for the role.  # noqa: E501

        :return: The description of this Role.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Role.

        Description for the role.  # noqa: E501

        :param description: The description of this Role.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def owner_email(self):
        """Gets the owner_email of this Role.  # noqa: E501

        Email of the user who currently owns the role.  # noqa: E501

        :return: The owner_email of this Role.  # noqa: E501
        :rtype: str
        """
        return self._owner_email

    @owner_email.setter
    def owner_email(self, owner_email):
        """Sets the owner_email of this Role.

        Email of the user who currently owns the role.  # noqa: E501

        :param owner_email: The owner_email of this Role.  # noqa: E501
        :type: str
        """

        self._owner_email = owner_email

    @property
    def created_by(self):
        """Gets the created_by of this Role.  # noqa: E501

        Email of the user who created the role.  # noqa: E501

        :return: The created_by of this Role.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Role.

        Email of the user who created the role.  # noqa: E501

        :param created_by: The created_by of this Role.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def privileges(self):
        """Gets the privileges of this Role.  # noqa: E501

        List of privileges associated with the role.  # noqa: E501

        :return: The privileges of this Role.  # noqa: E501
        :rtype: list[Privilege]
        """
        return self._privileges

    @privileges.setter
    def privileges(self, privileges):
        """Sets the privileges of this Role.

        List of privileges associated with the role.  # noqa: E501

        :param privileges: The privileges of this Role.  # noqa: E501
        :type: list[Privilege]
        """

        self._privileges = privileges

    @property
    def created_at(self):
        """Gets the created_at of this Role.  # noqa: E501

        ISO-8601 date of when the role was created.  # noqa: E501

        :return: The created_at of this Role.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Role.

        ISO-8601 date of when the role was created.  # noqa: E501

        :param created_at: The created_at of this Role.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Role, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Role):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.kafka_v3_security_config import KafkaV3SecurityConfig  # noqa: F401,E501
from rockset.swagger_client.models.status_kafka import StatusKafka  # noqa: F401,E501


class KafkaIntegration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'kafka_topic_names': 'list[str]',
        'source_status_by_topic': 'dict(str, StatusKafka)',
        'kafka_data_format': 'str',
        'connection_string': 'str',
        'use_v3': 'bool',
        'bootstrap_servers': 'str',
        'security_config': 'KafkaV3SecurityConfig'
    }

    attribute_map = {
        'kafka_topic_names': 'kafka_topic_names',
        'source_status_by_topic': 'source_status_by_topic',
        'kafka_data_format': 'kafka_data_format',
        'connection_string': 'connection_string',
        'use_v3': 'use_v3',
        'bootstrap_servers': 'bootstrap_servers',
        'security_config': 'security_config'
    }

    def __init__(self, **kwargs):  # noqa: E501
        """KafkaIntegration - a model defined in Swagger"""  # noqa: E501

        self._kafka_topic_names = None
        self._source_status_by_topic = None
        self._kafka_data_format = None
        self._connection_string = None
        self._use_v3 = None
        self._bootstrap_servers = None
        self._security_config = None
        self.discriminator = None

        self.kafka_topic_names = kwargs.pop('kafka_topic_names', None)
        self.source_status_by_topic = kwargs.pop('source_status_by_topic', None)
        self.kafka_data_format = kwargs.pop('kafka_data_format', None)
        self.connection_string = kwargs.pop('connection_string', None)
        self.use_v3 = kwargs.pop('use_v3', None)
        self.bootstrap_servers = kwargs.pop('bootstrap_servers', None)
        self.security_config = kwargs.pop('security_config', None)

    @property
    def kafka_topic_names(self):
        """Gets the kafka_topic_names of this KafkaIntegration.  # noqa: E501

        Kafka topics to tail  # noqa: E501

        :return: The kafka_topic_names of this KafkaIntegration.  # noqa: E501
        :rtype: list[str]
        """
        return self._kafka_topic_names

    @kafka_topic_names.setter
    def kafka_topic_names(self, kafka_topic_names):
        """Sets the kafka_topic_names of this KafkaIntegration.

        Kafka topics to tail  # noqa: E501

        :param kafka_topic_names: The kafka_topic_names of this KafkaIntegration.  # noqa: E501
        :type: list[str]
        """

        self._kafka_topic_names = kafka_topic_names

    @property
    def source_status_by_topic(self):
        """Gets the source_status_by_topic of this KafkaIntegration.  # noqa: E501

        The status of the Kafka source by topic  # noqa: E501

        :return: The source_status_by_topic of this KafkaIntegration.  # noqa: E501
        :rtype: dict(str, StatusKafka)
        """
        return self._source_status_by_topic

    @source_status_by_topic.setter
    def source_status_by_topic(self, source_status_by_topic):
        """Sets the source_status_by_topic of this KafkaIntegration.

        The status of the Kafka source by topic  # noqa: E501

        :param source_status_by_topic: The source_status_by_topic of this KafkaIntegration.  # noqa: E501
        :type: dict(str, StatusKafka)
        """

        self._source_status_by_topic = source_status_by_topic

    @property
    def kafka_data_format(self):
        """Gets the kafka_data_format of this KafkaIntegration.  # noqa: E501

        The format of the Kafka topics being tailed  # noqa: E501

        :return: The kafka_data_format of this KafkaIntegration.  # noqa: E501
        :rtype: str
        """
        return self._kafka_data_format

    @kafka_data_format.setter
    def kafka_data_format(self, kafka_data_format):
        """Sets the kafka_data_format of this KafkaIntegration.

        The format of the Kafka topics being tailed  # noqa: E501

        :param kafka_data_format: The kafka_data_format of this KafkaIntegration.  # noqa: E501
        :type: str
        """

        self._kafka_data_format = kafka_data_format

    @property
    def connection_string(self):
        """Gets the connection_string of this KafkaIntegration.  # noqa: E501

        kafka connection string  # noqa: E501

        :return: The connection_string of this KafkaIntegration.  # noqa: E501
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """Sets the connection_string of this KafkaIntegration.

        kafka connection string  # noqa: E501

        :param connection_string: The connection_string of this KafkaIntegration.  # noqa: E501
        :type: str
        """

        self._connection_string = connection_string

    @property
    def use_v3(self):
        """Gets the use_v3 of this KafkaIntegration.  # noqa: E501


        :return: The use_v3 of this KafkaIntegration.  # noqa: E501
        :rtype: bool
        """
        return self._use_v3

    @use_v3.setter
    def use_v3(self, use_v3):
        """Sets the use_v3 of this KafkaIntegration.


        :param use_v3: The use_v3 of this KafkaIntegration.  # noqa: E501
        :type: bool
        """

        self._use_v3 = use_v3

    @property
    def bootstrap_servers(self):
        """Gets the bootstrap_servers of this KafkaIntegration.  # noqa: E501


        :return: The bootstrap_servers of this KafkaIntegration.  # noqa: E501
        :rtype: str
        """
        return self._bootstrap_servers

    @bootstrap_servers.setter
    def bootstrap_servers(self, bootstrap_servers):
        """Sets the bootstrap_servers of this KafkaIntegration.


        :param bootstrap_servers: The bootstrap_servers of this KafkaIntegration.  # noqa: E501
        :type: str
        """

        self._bootstrap_servers = bootstrap_servers

    @property
    def security_config(self):
        """Gets the security_config of this KafkaIntegration.  # noqa: E501


        :return: The security_config of this KafkaIntegration.  # noqa: E501
        :rtype: KafkaV3SecurityConfig
        """
        return self._security_config

    @security_config.setter
    def security_config(self, security_config):
        """Sets the security_config of this KafkaIntegration.


        :param security_config: The security_config of this KafkaIntegration.  # noqa: E501
        :type: KafkaV3SecurityConfig
        """

        self._security_config = security_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(KafkaIntegration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KafkaIntegration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.status_kafka import StatusKafka  # noqa: F401,E501


class SourceKafka(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'kafka_topic_name': 'str',
        'status': 'StatusKafka',
        'use_v3': 'bool',
        'offset_reset_policy': 'str'
    }

    attribute_map = {
        'kafka_topic_name': 'kafka_topic_name',
        'status': 'status',
        'use_v3': 'use_v3',
        'offset_reset_policy': 'offset_reset_policy'
    }

    def __init__(self, kafka_topic_name, **kwargs):  # noqa: E501
        """SourceKafka - a model defined in Swagger"""  # noqa: E501

        self._kafka_topic_name = None
        self._status = None
        self._use_v3 = None
        self._offset_reset_policy = None
        self.discriminator = None

        self.kafka_topic_name = kafka_topic_name
        self.status = kwargs.pop('status', None)
        self.use_v3 = kwargs.pop('use_v3', None)
        self.offset_reset_policy = kwargs.pop('offset_reset_policy', None)

    @property
    def kafka_topic_name(self):
        """Gets the kafka_topic_name of this SourceKafka.  # noqa: E501

        The Kafka topic to be tailed  # noqa: E501

        :return: The kafka_topic_name of this SourceKafka.  # noqa: E501
        :rtype: str
        """
        return self._kafka_topic_name

    @kafka_topic_name.setter
    def kafka_topic_name(self, kafka_topic_name):
        """Sets the kafka_topic_name of this SourceKafka.

        The Kafka topic to be tailed  # noqa: E501

        :param kafka_topic_name: The kafka_topic_name of this SourceKafka.  # noqa: E501
        :type: str
        """

        self._kafka_topic_name = kafka_topic_name

    @property
    def status(self):
        """Gets the status of this SourceKafka.  # noqa: E501

        Kafka source status  # noqa: E501

        :return: The status of this SourceKafka.  # noqa: E501
        :rtype: StatusKafka
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SourceKafka.

        Kafka source status  # noqa: E501

        :param status: The status of this SourceKafka.  # noqa: E501
        :type: StatusKafka
        """

        self._status = status

    @property
    def use_v3(self):
        """Gets the use_v3 of this SourceKafka.  # noqa: E501


        :return: The use_v3 of this SourceKafka.  # noqa: E501
        :rtype: bool
        """
        return self._use_v3

    @use_v3.setter
    def use_v3(self, use_v3):
        """Sets the use_v3 of this SourceKafka.


        :param use_v3: The use_v3 of this SourceKafka.  # noqa: E501
        :type: bool
        """

        self._use_v3 = use_v3

    @property
    def offset_reset_policy(self):
        """Gets the offset_reset_policy of this SourceKafka.  # noqa: E501


        :return: The offset_reset_policy of this SourceKafka.  # noqa: E501
        :rtype: str
        """
        return self._offset_reset_policy

    @offset_reset_policy.setter
    def offset_reset_policy(self, offset_reset_policy):
        """Sets the offset_reset_policy of this SourceKafka.


        :param offset_reset_policy: The offset_reset_policy of this SourceKafka.  # noqa: E501
        :type: str
        """

        self._offset_reset_policy = offset_reset_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SourceKafka, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceKafka):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SourceFileUpload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_name': 'str',
        'file_size': 'int',
        'file_upload_time': 'str'
    }

    attribute_map = {
        'file_name': 'file_name',
        'file_size': 'file_size',
        'file_upload_time': 'file_upload_time'
    }

    def __init__(self, file_name, file_size, file_upload_time, **kwargs):  # noqa: E501
        """SourceFileUpload - a model defined in Swagger"""  # noqa: E501

        self._file_name = None
        self._file_size = None
        self._file_upload_time = None
        self.discriminator = None

        self.file_name = file_name
        self.file_size = file_size
        self.file_upload_time = file_upload_time

    @property
    def file_name(self):
        """Gets the file_name of this SourceFileUpload.  # noqa: E501

        name of the file  # noqa: E501

        :return: The file_name of this SourceFileUpload.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this SourceFileUpload.

        name of the file  # noqa: E501

        :param file_name: The file_name of this SourceFileUpload.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def file_size(self):
        """Gets the file_size of this SourceFileUpload.  # noqa: E501

        size of the file in bytes  # noqa: E501

        :return: The file_size of this SourceFileUpload.  # noqa: E501
        :rtype: int
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        """Sets the file_size of this SourceFileUpload.

        size of the file in bytes  # noqa: E501

        :param file_size: The file_size of this SourceFileUpload.  # noqa: E501
        :type: int
        """

        self._file_size = file_size

    @property
    def file_upload_time(self):
        """Gets the file_upload_time of this SourceFileUpload.  # noqa: E501

        time of file upload  # noqa: E501

        :return: The file_upload_time of this SourceFileUpload.  # noqa: E501
        :rtype: str
        """
        return self._file_upload_time

    @file_upload_time.setter
    def file_upload_time(self, file_upload_time):
        """Sets the file_upload_time of this SourceFileUpload.

        time of file upload  # noqa: E501

        :param file_upload_time: The file_upload_time of this SourceFileUpload.  # noqa: E501
        :type: str
        """

        self._file_upload_time = file_upload_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SourceFileUpload, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceFileUpload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from rockset.swagger_client.models.query_parameter import QueryParameter  # noqa: F401,E501


class QueryRequestSql(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query': 'str',
        'generate_warnings': 'bool',
        'profiling_enabled': 'bool',
        'parameters': 'list[QueryParameter]',
        'default_row_limit': 'int',
        'paginate': 'bool',
        'initial_paginate_response_doc_count': 'int'
    }

    attribute_map = {
        'query': 'query',
        'generate_warnings': 'generate_warnings',
        'profiling_enabled': 'profiling_enabled',
        'parameters': 'parameters',
        'default_row_limit': 'default_row_limit',
        'paginate': 'paginate',
        'initial_paginate_response_doc_count': 'initial_paginate_response_doc_count'
    }

    def __init__(self, query, **kwargs):  # noqa: E501
        """QueryRequestSql - a model defined in Swagger"""  # noqa: E501

        self._query = None
        self._generate_warnings = None
        self._profiling_enabled = None
        self._parameters = None
        self._default_row_limit = None
        self._paginate = None
        self._initial_paginate_response_doc_count = None
        self.discriminator = None

        self.query = query
        self.generate_warnings = kwargs.pop('generate_warnings', None)
        self.profiling_enabled = kwargs.pop('profiling_enabled', None)
        self.parameters = kwargs.pop('parameters', None)
        self.default_row_limit = kwargs.pop('default_row_limit', None)
        self.paginate = kwargs.pop('paginate', None)
        self.initial_paginate_response_doc_count = kwargs.pop('initial_paginate_response_doc_count', None)

    @property
    def query(self):
        """Gets the query of this QueryRequestSql.  # noqa: E501

        SQL query string.  # noqa: E501

        :return: The query of this QueryRequestSql.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this QueryRequestSql.

        SQL query string.  # noqa: E501

        :param query: The query of this QueryRequestSql.  # noqa: E501
        :type: str
        """

        self._query = query

    @property
    def generate_warnings(self):
        """Gets the generate_warnings of this QueryRequestSql.  # noqa: E501

        Flag to enable warnings. Warnings can help debug query issues but negatively affect performance.  # noqa: E501

        :return: The generate_warnings of this QueryRequestSql.  # noqa: E501
        :rtype: bool
        """
        return self._generate_warnings

    @generate_warnings.setter
    def generate_warnings(self, generate_warnings):
        """Sets the generate_warnings of this QueryRequestSql.

        Flag to enable warnings. Warnings can help debug query issues but negatively affect performance.  # noqa: E501

        :param generate_warnings: The generate_warnings of this QueryRequestSql.  # noqa: E501
        :type: bool
        """

        self._generate_warnings = generate_warnings

    @property
    def profiling_enabled(self):
        """Gets the profiling_enabled of this QueryRequestSql.  # noqa: E501

        Flag to generate a performance profile for this query.  # noqa: E501

        :return: The profiling_enabled of this QueryRequestSql.  # noqa: E501
        :rtype: bool
        """
        return self._profiling_enabled

    @profiling_enabled.setter
    def profiling_enabled(self, profiling_enabled):
        """Sets the profiling_enabled of this QueryRequestSql.

        Flag to generate a performance profile for this query.  # noqa: E501

        :param profiling_enabled: The profiling_enabled of this QueryRequestSql.  # noqa: E501
        :type: bool
        """

        self._profiling_enabled = profiling_enabled

    @property
    def parameters(self):
        """Gets the parameters of this QueryRequestSql.  # noqa: E501

        List of named parameters.  # noqa: E501

        :return: The parameters of this QueryRequestSql.  # noqa: E501
        :rtype: list[QueryParameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this QueryRequestSql.

        List of named parameters.  # noqa: E501

        :param parameters: The parameters of this QueryRequestSql.  # noqa: E501
        :type: list[QueryParameter]
        """

        self._parameters = parameters

    @property
    def default_row_limit(self):
        """Gets the default_row_limit of this QueryRequestSql.  # noqa: E501

        Row limit to use. Limits specified in the query text will override this default.  # noqa: E501

        :return: The default_row_limit of this QueryRequestSql.  # noqa: E501
        :rtype: int
        """
        return self._default_row_limit

    @default_row_limit.setter
    def default_row_limit(self, default_row_limit):
        """Sets the default_row_limit of this QueryRequestSql.

        Row limit to use. Limits specified in the query text will override this default.  # noqa: E501

        :param default_row_limit: The default_row_limit of this QueryRequestSql.  # noqa: E501
        :type: int
        """

        self._default_row_limit = default_row_limit

    @property
    def paginate(self):
        """Gets the paginate of this QueryRequestSql.  # noqa: E501

        Flag to paginate and store the results of this query for later / sequential retrieval.  # noqa: E501

        :return: The paginate of this QueryRequestSql.  # noqa: E501
        :rtype: bool
        """
        return self._paginate

    @paginate.setter
    def paginate(self, paginate):
        """Sets the paginate of this QueryRequestSql.

        Flag to paginate and store the results of this query for later / sequential retrieval.  # noqa: E501

        :param paginate: The paginate of this QueryRequestSql.  # noqa: E501
        :type: bool
        """

        self._paginate = paginate

    @property
    def initial_paginate_response_doc_count(self):
        """Gets the initial_paginate_response_doc_count of this QueryRequestSql.  # noqa: E501

        Number of documents to return in addition to paginating for this query call. Only relevant if `paginate` flag is also set.  # noqa: E501

        :return: The initial_paginate_response_doc_count of this QueryRequestSql.  # noqa: E501
        :rtype: int
        """
        return self._initial_paginate_response_doc_count

    @initial_paginate_response_doc_count.setter
    def initial_paginate_response_doc_count(self, initial_paginate_response_doc_count):
        """Sets the initial_paginate_response_doc_count of this QueryRequestSql.

        Number of documents to return in addition to paginating for this query call. Only relevant if `paginate` flag is also set.  # noqa: E501

        :param initial_paginate_response_doc_count: The initial_paginate_response_doc_count of this QueryRequestSql.  # noqa: E501
        :type: int
        """

        self._initial_paginate_response_doc_count = initial_paginate_response_doc_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QueryRequestSql, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryRequestSql):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)



# coding: utf-8

"""
    REST API

    Rockset's REST API allows for creating and managing all resources in Rockset. Each supported endpoint is documented below.  All requests must be authorized with a Rockset API key, which can be created in the [Rockset console](https://console.rockset.com). The API key must be provided as `ApiKey <api_key>` in the `Authorization` request header. For example: ``` Authorization: ApiKey aB35kDjg93J5nsf4GjwMeErAVd832F7ad4vhsW1S02kfZiab42sTsfW5Sxt25asT ```  All endpoints are only accessible via https.  Build something awesome!  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PatchOperation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'op': 'str',
        'path': 'str',
        'value': 'object',
        '_from': 'str'
    }

    attribute_map = {
        'op': 'op',
        'path': 'path',
        'value': 'value',
        '_from': 'from'
    }

    def __init__(self, op, path, **kwargs):  # noqa: E501
        """PatchOperation - a model defined in Swagger"""  # noqa: E501

        self._op = None
        self._path = None
        self._value = None
        self.__from = None
        self.discriminator = None

        self.op = op
        self.path = path
        self.value = kwargs.pop('value', None)
        self._from = kwargs.pop('_from', None)

    @property
    def op(self):
        """Gets the op of this PatchOperation.  # noqa: E501

        [JSON Patch operation](https://datatracker.ietf.org/doc/html/rfc6902#page-4) to be performed in this patch. Case insensitive.  # noqa: E501

        :return: The op of this PatchOperation.  # noqa: E501
        :rtype: str
        """
        return self._op

    @op.setter
    def op(self, op):
        """Sets the op of this PatchOperation.

        [JSON Patch operation](https://datatracker.ietf.org/doc/html/rfc6902#page-4) to be performed in this patch. Case insensitive.  # noqa: E501

        :param op: The op of this PatchOperation.  # noqa: E501
        :type: str
        """

        self._op = op

    @property
    def path(self):
        """Gets the path of this PatchOperation.  # noqa: E501

        [JSON Pointer](https://datatracker.ietf.org/doc/html/rfc6901) referencing a location in the target document where the operation is performed  # noqa: E501

        :return: The path of this PatchOperation.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this PatchOperation.

        [JSON Pointer](https://datatracker.ietf.org/doc/html/rfc6901) referencing a location in the target document where the operation is performed  # noqa: E501

        :param path: The path of this PatchOperation.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def value(self):
        """Gets the value of this PatchOperation.  # noqa: E501

        Value used in the patch operation. Required for `ADD`, `REPLACE`, `TEST`, and `INCREMENT` operations.  # noqa: E501

        :return: The value of this PatchOperation.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PatchOperation.

        Value used in the patch operation. Required for `ADD`, `REPLACE`, `TEST`, and `INCREMENT` operations.  # noqa: E501

        :param value: The value of this PatchOperation.  # noqa: E501
        :type: object
        """

        self._value = value

    @property
    def _from(self):
        """Gets the _from of this PatchOperation.  # noqa: E501

        [JSON Pointer](https://datatracker.ietf.org/doc/html/rfc6901) referencing a location in the target document. Required for `COPY` and `MOVE` operations.  # noqa: E501

        :return: The _from of this PatchOperation.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this PatchOperation.

        [JSON Pointer](https://datatracker.ietf.org/doc/html/rfc6901) referencing a location in the target document. Required for `COPY` and `MOVE` operations.  # noqa: E501

        :param _from: The _from of this PatchOperation.  # noqa: E501
        :type: str
        """

        self.__from = _from

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PatchOperation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PatchOperation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

    def __getitem__(self, item):
        return getattr(self, item)

    def get(self, item):
        return getattr(self, item)

    def items(self):
        return self.to_dict().items()

    def __setitem__(self, item, value):
        return seattr(self, item, value)
